@@ -23,8 +23,8 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include "glpimg.h"
+#include "glpset.h"
 
 /*----------------------------------------------------------------------
 -- reset_rgb - initialize color map table by default spectrum.
@@ -214,7 +214,7 @@ void reset_rgb(IMG *img)
             for (c = 0x00; c <= 0xFF; c++) img->rgb[c] = dac[c];
             break;
          default:
-            assert(img->type != img->type);
+            insist(img->type != img->type);
       }
       return;
 }
