@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <limits.h>
 #include <errno.h>
 #include <stdio.h>
@@ -95,7 +94,7 @@ int save_as_bmp(IMG *img, char *fname)
             bitcnt = 8;
             break;
          default:
-            assert(img->type != img->type);
+            insist(img->type != img->type);
       }
       /* struct BMPFILEHEADER */
       /* UINT bfType */
@@ -200,7 +199,7 @@ int save_as_bmp(IMG *img, char *fname)
             }
             break;
          default:
-            assert(img->type != img->type);
+            insist(img->type != img->type);
       }
       fflush(fp);
       if (ferror(fp))
