@@ -44,7 +44,7 @@ typedef struct AVLTREE AVLTREE;
 typedef struct AVLNODE AVLNODE;
 
 struct AVLTREE
-{     /* Adelson-Velsky & Landis' binary tree (AVL-tree) */
+{     /* Adelson-Velsky & Landis binary tree (AVL-tree) */
       POOL *pool;
       /* memory pool holding tree nodes */
       int (*comp)(void *, void *);
