@@ -34,6 +34,7 @@
 #define delete_lp             glp_delete_lp
 #define delete_lpsol          glp_delete_lpsol
 #define extract_lp            glp_extract_lp
+#define extract_prob          glp_extract_prob
 #define prepro_lp             glp_prepro_lp
 #define store_lpsol           glp_store_lpsol
 
@@ -185,6 +186,9 @@ extern void delete_lpsol(LPSOL *sol);
 extern LP *extract_lp(void);
 /* extract LP problem data from the workspace */
 
+extern LP *extract_prob(void *lpi);
+/* extract LP problem data from LPI object */
+
 extern int prepro_lp(LP *lp);
 /* perform preprocessing LP/MIP problem */
 
