@@ -47,9 +47,6 @@
 #define get_atomv             glp_get_atomv
 #define clear_pool            glp_clear_pool
 #define delete_pool           glp_delete_pool
-#define open_data             glp_open_data
-#define scan_data             glp_scan_data
-#define close_data            glp_close_data
 
 extern void print(char *fmt, ...);
 /* print informative message */
@@ -164,27 +161,6 @@ extern void clear_pool(POOL *pool);
 extern void delete_pool(POOL *pool);
 /* delete memory pool */
 
-typedef struct DATA DATA;
-
-struct DATA
-{     /* data stream */
-      char *fn;
-      /* name of an input text file */
-      void *fp; /* FILE *fp; */
-      /* stream assigned to the input text file */
-      int cn;
-      /* number of read text lines */
-};
-
-extern DATA *open_data(char *fname);
-/* open data stream */
-
-extern int scan_data(DATA *ds, ...);
-/* read data from data stream */
-
-extern void close_data(DATA *ds);
-/* close data stream */
-
 #endif
 
 /* eof */
